#!/bin/bash

###################################################################################################
# Simple shell script to read in the WSJT-X ADI format logfile and convert it to HTML for website #
#                                                                                                 #
# Mike T - M0AWS - 27/01/22                                                                       #
#                                                                                                 #
###################################################################################################

###################################################################################################
# History:                                                                                        #
#           v0.1 - 27/01/22 - M0AWS - Initial code write                                          #
#           v0.2 - 28/01/22 - M0AWS - Tidy up formatting                                          #
#           v0.3 - 31/01/22 - M0AWS - Code tidy and improvement                                   #
#           v0.4 - 31/01/22 - M0AWS - Added colour to table via CSS                               #
#           v0.5 - 03/02/22 - M0AWS - Rewritten function process_log() to use column name         #
#				      to identify data instead of position in row                 #
#           v0.6 - 10/03/22 - M0AWS - Added code to include map of digital contacts               #
#           v0.7 - 01/04/22 - M0AWS - Added code to collect stats                                 #
#           v0.8 - 01/04/22 - M0AWS - Added code display status whilst running                    #
#           v0.9 - 04/04/22 - M0AWS - Added code to calculate mW per mile                         #
#           v1.0 - 04/04/22 - M0AWS - Added code to calculate runtime                             #
#           v1.1 - 28/04/22 - M0AWS - Changed run sequence ready for new functionality            #
#           v1.2 - 28/04/22 - M0AWS - Added code to calculate lowest mW/Mile contact              #
#           v1.3 - 28/04/22 - M0AWS - Added code to calculate longest distance contact            #
#           v1.4 - 01/05/22 - M0AWS - Added code to  handle log name passed on commandline        #
#				      so script can be called from within qdlog                   #
#           v1.5 - 02/05/22 - M0AWS - Added code for platform dependant TAC                       #
#           v1.6 - 08/05/22 - M0AWS - Altered process information code                            #
#           v1.7 - 15/05/22 - M0AWS - Started adding code to calculate distance between two       #
#                                     maidenhead grid squares removing need for distance to be    #
#                                     manually entered into the comments field                    #
#           v1.8 - 16/05/22 - M0AWS - Started adding code to calculate distance between two       #
#                                     maidenhead grid squares in kilomters                        #
#           v1.9 - 16/05/22 - M0AWS - Rewrote code for lowest mw/mile/km & Longest Distance QSO   #
#           v2.0 - 16/05/22 - M0AWS - Squashed some bugs WWL code                                 #
#           v2.1 - 20/05/22 - M0AWS - Changed code so that LOGMODE must be passed as option 2     #
#                                     when alternative adi file passed as option 1 when           #
#                                     called on commandline. HTML Title now dynamic based on      #
#				      LOGMODE rather than being hard coded so adi2html can be     #
#                                     used to process QDLOG adi files as well                     #
#                                                                                                 #
###################################################################################################


############################
# Global Vars

START=`date +%s`
VERSION="v2.1"
CALLSIGN="M0AWS"
DATE=`date`
ADIFILENAME="./wsjtx_log.adi" # Can be overidden if alternative log passed as option one commandline
HTMLFILENAME="./WSJT_log.html" # Automagically overidden if alternative log passed as option 1 on commandline
MAPFILE="m0aws-wsjtx-log-map.png" # Automagically overidden if alternative log passed as option 1 on commandline
LOGMODE="WSJTX" # Automagically overidden if alternative log passed as option 1 on commandline
TEMPFILE1="./adi2html1.tmp" # Holds HTML page body
TEMPFILE2="./adi2html2.tmp" # Holds lowest mW/Mile data
TEMPFILE3="./adi2html3.tmp" # Holds highest distance data
LOWESTMW=1000
LOWESTMWQSO=""
HIGHESTDIST=0
HIGHESTDISTQSO=""
TAC=""
WWL=`which wwl`
UNIT="miles" # Can be 'km' or 'miles'
DISTMILES=0
DISTKM=0

############################
# Define Functions

function process_log() {

	echo "Processing $ADIFILENAME entries ..."

	$TAC $ADIFILENAME | while read LINE
	do
  	case $LINE in
		
		*call:*) DXCALL=`echo $LINE | grep -o 'call:[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 GRIDSQUARE=`echo $LINE | grep -o '<gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 MODE=`echo $LINE | grep -o 'mode[^[:space:]]*' | awk -F">" '{print $2}'`
			 case $MODE in

				"MFSK") MODE=`echo $LINE | awk -F"<mode:" '{print $2}' | awk -F" " '{print $1" "$2}' | cut -c 3-`
						;;
			 esac
		 	 RSTSENT=`echo $LINE | grep -o 'rst_sent[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 RSTRXD=`echo $LINE | grep -o 'rst_rcvd[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 QSODATE=`echo $LINE | grep -o 'qso_date:[^[:space:]]*' | awk -F">" '{print $2}' | sed -n -e "s_\(....\)\(..\)\(..\)_\3/\2/\1_p"`
		 	 TIMEON=`echo $LINE | grep -o 'time_on[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
		 	 #QSODATEOFF=`echo $LINE | grep -o 'qso_date_off[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 TIMEOFF=`echo $LINE | grep -o 'time_off[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
		 	 BAND=`echo $LINE | grep -o 'band[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 FREQ=`echo $LINE | grep -o 'freq[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 #MYCALL=`echo $LINE | grep -o 'station_callsign[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 MYGRIDSQ=`echo $LINE | grep -o 'my_gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 TXPWR=`echo $LINE | grep -o 'tx_pwr[^[:space:]]*' | awk -F">" '{print $2"w"}'`
		 	 COMMENT=`echo $LINE | awk -F"<comment" '{print $2}' | awk -F">" '{print $2}' | sed 's/<operator:.*//g' | sed 's/<eor//g' | sed 's/miles/Miles/g'`
			
			 case $COMMENT in

				*Miles*) # Distance already in comments field so nothing to do
						;;

				   *km*) # Distance already in comments field so nothing to do
						;;
          
				      *) case $GRIDSQUARE in

						"") # Do nothing as no DX gridsqaure available
							;;

				 		 *) DISTKM=`$WWL $MYGRIDSQ $GRIDSQUARE | awk '{print $2}'`
				    		    case $UNIT in

							"miles") DISTMILES=`echo "$DISTKM * 0.621371" | bc`
								 DISTMILES=`printf "%.0f" $DISTMILES`
						 		 COMMENT=`echo -n "$DISTMILES Miles $COMMENT"`
									;;

					   		   "km") COMMENT=`echo -n "$DISTKM km $COMMENT"`
									;;
		
					      		      *) echo "ERROR: Distance unit not set!"
									;;
				    		   esac
						    ;;
					 esac
					  ;;

			 esac
			
			 case $COMMENT in
		
					*Mile*) NUMMILES=`echo $COMMENT | awk -F"Mile" '{print $1}'`
						RESULT=$(echo "${HIGHESTDIST}<${NUMMILES}" | bc)
						if [ $RESULT = 1 ]
							then
								HIGHESTDIST=$NUMMILES
								echo "$LINE" > $TEMPFILE3
						fi
				 		WATTS=`echo $TXPWR | sed 's/w//g'`
				 		MWPERMILE=`echo "scale=2; $WATTS*1000/$NUMMILES" | bc`
                        			RESULT=$(echo "${MWPERMILE}<${LOWESTMW}" | bc)
                        			if [ $RESULT = 1 ]
                                			then
                                        			LOWESTMW=$MWPERMILE
                                        			echo "$LINE" > $TEMPFILE2
                        			fi
				 		;;

					  *km*) NUMKMS=`echo $COMMENT | awk -F"km" '{print $1}'`
						RESULT=$(echo "${HIGHESTDIST}<${NUMKMS}" | bc)
						if [ $RESULT = 1 ]
                                                        then
                                                                HIGHESTDIST=$NUMKMS
                                                                echo "$LINE" > $TEMPFILE3
                                                fi
						WATTS=`echo $TXPWR | sed 's/w//g'`
						MWPERKM=`echo "scale=2; $WATTS*1000/$NUMKMS" | bc`
						RESULT=$(echo "${MWPERKM}<${LOWESTMW}" | bc)
						if [ $RESULT = 1 ]
                                                        then
                                                                LOWESTMW=$MWPERKM
                                                                echo "$LINE" > $TEMPFILE2
                                                fi
						;;

			       		     *) MWPERMILE=""
						MWPERKM=""
				 		;;
			esac

			case $UNIT in

				"miles") echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n<td>$MWPERMILE</td>\n</tr>" >> $TEMPFILE1
						;;

				   "km") echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n<td>$MWPERKM</td>\n</tr>" >> $TEMPFILE1
                                                ;;

			esac
		 	;;
  	esac
		
	done

}


function write_html_header() {
	echo "Writing HTML headers ..."
	echo -e "<!DOCTYPE html>\n<html>\n<style>\ntable, th, td {border:1px solid black;}\n       th { background-color: #A0A0A0; }\n       tr:nth-child(odd) {background-color: #E0E0E0;}\n       tr:nth-child(even) {background-color: #FFFF99;}\n</style>\n<body>\n<center><h2>$CALLSIGN $LOGMODE Log updated $DATE</h2></center>\n" > $HTMLFILENAME

	# Hash out the line below if you don't want to include a map in the webpage.
	# Map must be generated manually and uploaded to website.
	# Use https://www.qsomap.org/qsomapadifcq.php to generate the map
	#
	echo -e "<CENTER><img src=\"/$MAPFILE\" alt=\"$CALLSIGN $LOGMODE contacts map\" style=\"width:1024px;height:720;\"></CENTER>" >> $HTMLFILENAME
	#

	# QSOs per band table
	echo "<center><h4><b>Number of QSOs per Band</b></h4>" >> $HTMLFILENAME
	echo -e "<table style=\"width:100%\">\n<tr>\n<th>160m</th>\n<th>80m</th>\n<th>60m</th>\n<th>40m</th>\n<th>30m</th>\n<th>20m</th>\n<th>17m</th>\n<th>15m</th>\n<th>12m</th>\n<th>10m</th>\n<th>6m</th>\n<th>4m</th>\n<th>2m</th>\n<th>70cm</th>\n<th>TOTAL</th></tr>" >> $HTMLFILENAME
	echo -e "<tr>\n<td>$COUNT160M</td>\n<td>$COUNT80M</td>\n<td>$COUNT60M</td>\n<td>$COUNT40M</td>\n<td>$COUNT30M</td>\n<td>$COUNT20M</td>\n<td>$COUNT17M</td>\n<td>$COUNT15M</td>\n<td>$COUNT12M</td>\n<td>$COUNT10M</td>\n<td>$COUNT6M</td>\n<td>$COUNT4M</td>\n<td>$COUNT2M</td>\n<td>$COUNT70CM</td>\n<td>$TOTAL</td>\n</tr>\n</table>\n<p>" >> $HTMLFILENAME

	# Lowest mw/Mile table
	
	if [ -f "$TEMPFILE2" ]
		then
			LOWESTMWQSO=`cat $TEMPFILE2`
			case $UNIT in
		
				"miles") echo "<center><h4><b>Lowest Milliwatt per Mile</b></h4>" >> $HTMLFILENAME
					 echo -e "<table style=\"width:100%\">\n<tr>\n<th>QSO DATE</th>\n<th>DX CALLSIGN</th>\n<th>DX GRID</th>\n<th>MODE</th>\n<th>SNR SENT</th>\n<th>SNR RXD</th>\n<th>TIME ON</th>\n<th>TIME OFF</th>\n<th>BAND</th>\n<th>FREQ Mhz</th>\n<th>TX PWR</th>\n<th>COMMENT</th>\n<th>mW/Mile</th>\n</tr>" >> $HTMLFILENAME
						;;

				   "km") echo "<center><h4><b>Lowest Milliwatt per Kilometer</b></h4>" >> $HTMLFILENAME
					 echo -e "<table style=\"width:100%\">\n<tr>\n<th>QSO DATE</th>\n<th>DX CALLSIGN</th>\n<th>DX GRID</th>\n<th>MODE</th>\n<th>SNR SENT</th>\n<th>SNR RXD</th>\n<th>TIME ON</th>\n<th>TIME OFF</th>\n<th>BAND</th>\n<th>FREQ Mhz</th>\n<th>TX PWR</th>\n<th>COMMENT</th>\n<th>mW/km</th>\n</tr>" >> $HTMLFILENAME
						;;
			esac

			DXCALL=`echo $LOWESTMWQSO | grep -o 'call:[^[:space:]]*' | awk -F">" '{print $2}'`
        		GRIDSQUARE=`echo $LOWESTMWQSO | grep -o '<gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
        		MODE=`echo $LOWESTMWQSO | grep -o 'mode[^[:space:]]*' | awk -F">" '{print $2}'`
			case $MODE in

                                MFSK*) MODE=`echo $LINE | awk -F"<mode:" '{print $2}' | awk -F" " '{print $1" "$2}' | cut -c 3-`
                                        ;;
                        esac
        		RSTSENT=`echo $LOWESTMWQSO | grep -o 'rst_sent[^[:space:]]*' | awk -F">" '{print $2}'`
        		RSTRXD=`echo $LOWESTMWQSO | grep -o 'rst_rcvd[^[:space:]]*' | awk -F">" '{print $2}'`
        		QSODATE=`echo $LOWESTMWQSO | grep -o 'qso_date:[^[:space:]]*' | awk -F">" '{print $2}' | sed -n -e "s_\(....\)\(..\)\(..\)_\3/\2/\1_p"`
        		TIMEON=`echo $LOWESTMWQSO | grep -o 'time_on[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
        		#QSODATEOFF=`echo $LOWESTMWQSO | grep -o 'qso_date_off[^[:space:]]*' | awk -F">" '{print $2}'`
        		TIMEOFF=`echo $LOWESTMWQSO | grep -o 'time_off[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
        		BAND=`echo $LOWESTMWQSO | grep -o 'band[^[:space:]]*' | awk -F">" '{print $2}'`
        		FREQ=`echo $LOWESTMWQSO | grep -o 'freq[^[:space:]]*' | awk -F">" '{print $2}'`
        		MYCALL=`echo $LOWESTMWQSO | grep -o 'station_callsign[^[:space:]]*' | awk -F">" '{print $2}'`
        		MYGRIDSQ=`echo $LOWESTMWQSO | grep -o 'my_gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
        		TXPWR=`echo $LOWESTMWQSO | grep -o 'tx_pwr[^[:space:]]*' | awk -F">" '{print $2"w"}'`
        		COMMENT=`echo $LOWESTMWQSO | awk -F"<comment" '{print $2}' | awk -F">" '{print $2}' | sed 's/<operator:.*//g' | sed 's/<eor//g' | sed 's/miles/Miles/g'`
        		WATTS=`echo $TXPWR | sed 's/w//g'`
			case $UNIT in

				"miles") DISTKM=`$WWL $MYGRIDSQ $GRIDSQUARE | awk '{print $2}'`
					 DISTMILES=`echo "$DISTKM * 0.621371" | bc`
                                         DISTMILES=`printf "%.0f" $DISTMILES`
                                         COMMENT=`echo -n "$DISTMILES Miles $COMMENT"`
					 MWPERMILE=`echo "scale=2; $WATTS*1000/$DISTMILES" | bc`
					 echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n<td>$MWPERMILE</td>\n</tr>" >> $HTMLFILENAME
					 echo -e "</table>\n<p>" >> $HTMLFILENAME
						;;
				   "km") DISTKM=`$WWL $MYGRIDSQ $GRIDSQUARE | awk '{print $2}'`
					 COMMENT=`echo -n "$DISTKM km $COMMENT"`
					 MWPERKM=`echo "scale=2; $WATTS*1000/$DISTKM" | bc`
					 echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n<td>$MWPERKM</td>\n</tr>" >> $HTMLFILENAME
                                         echo -e "</table>\n<p>" >> $HTMLFILENAME

			esac
	fi

	# Longest distance table

	if [ -f "$TEMPFILE3" ]
                then
                        HIGHESTDISTQSO=`cat $TEMPFILE3`
                        echo "<center><h4><b>Longest Distance QSO</b></h4>" >> $HTMLFILENAME
			case $UNIT in

				"miles") echo -e "<table style=\"width:100%\">\n<tr>\n<th>QSO DATE</th>\n<th>DX CALLSIGN</th>\n<th>DX GRID</th>\n<th>MODE</th>\n<th>SNR SENT</th>\n<th>SNR RXD</th>\n<th>TIME ON</th>\n<th>TIME OFF</th>\n<th>BAND</th>\n<th>FREQ Mhz</th>\n<th>TX PWR</th>\n<th>COMMENT</th>\n<th>mW/Mile</th>\n</tr>" >> $HTMLFILENAME
						;;

				   "km") echo -e "<table style=\"width:100%\">\n<tr>\n<th>QSO DATE</th>\n<th>DX CALLSIGN</th>\n<th>DX GRID</th>\n<th>MODE</th>\n<th>SNR SENT</th>\n<th>SNR RXD</th>\n<th>TIME ON</th>\n<th>TIME OFF</th>\n<th>BAND</th>\n<th>FREQ Mhz</th>\n<th>TX PWR</th>\n<th>COMMENT</th>\n<th>mW/km</th>\n</tr>" >> $HTMLFILENAME
                                                ;;

			esac
                        DXCALL=`echo $HIGHESTDISTQSO | grep -o 'call:[^[:space:]]*' | awk -F">" '{print $2}'`
                        GRIDSQUARE=`echo $HIGHESTDISTQSO | grep -o '<gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
                        MODE=`echo $HIGHESTDISTQSO | grep -o 'mode[^[:space:]]*' | awk -F">" '{print $2}'`
			case $MODE in

                                MFSK*) MODE=`echo $LINE | awk -F"<mode:" '{print $2}' | awk -F" " '{print $1" "$2}' | cut -c 3-`
                                        ;;
                        esac
                        RSTSENT=`echo $HIGHESTDISTQSO | grep -o 'rst_sent[^[:space:]]*' | awk -F">" '{print $2}'`
                        RSTRXD=`echo $HIGHESTDISTQSO | grep -o 'rst_rcvd[^[:space:]]*' | awk -F">" '{print $2}'`
                        QSODATE=`echo $HIGHESTDISTQSO | grep -o 'qso_date:[^[:space:]]*' | awk -F">" '{print $2}' | sed -n -e "s_\(....\)\(..\)\(..\)_\3/\2/\1_p"`
                        TIMEON=`echo $HIGHESTDISTQSO | grep -o 'time_on[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
                        #QSODATEOFF=`echo $HIGHESTDISTQSO | grep -o 'qso_date_off[^[:space:]]*' | awk -F">" '{print $2}'`
                        TIMEOFF=`echo $HIGHESTDISTQSO | grep -o 'time_off[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
                        BAND=`echo $HIGHESTDISTQSO | grep -o 'band[^[:space:]]*' | awk -F">" '{print $2}'`
                        FREQ=`echo $HIGHESTDISTQSO | grep -o 'freq[^[:space:]]*' | awk -F">" '{print $2}'`
                        MYCALL=`echo $HIGHESTDISTQSO | grep -o 'station_callsign[^[:space:]]*' | awk -F">" '{print $2}'`
                        MYGRIDSQ=`echo $HIGHESTDISTQSO | grep -o 'my_gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
                        TXPWR=`echo $HIGHESTDISTQSO | grep -o 'tx_pwr[^[:space:]]*' | awk -F">" '{print $2"w"}'`
                        COMMENT=`echo $HIGHESTDISTQSO | awk -F"<comment" '{print $2}' | awk -F">" '{print $2}' | sed 's/<operator:.*//g' | sed 's/<eor//g' | sed 's/miles/Miles/g'`
                        WATTS=`echo $TXPWR | sed 's/w//g'`

			case $UNIT in

				"miles") DISTKM=`$WWL $MYGRIDSQ $GRIDSQUARE | awk '{print $2}'`
					 DISTMILES=`echo "$DISTKM * 0.621371" | bc`
                                         DISTMILES=`printf "%.0f" $DISTMILES`
                                         COMMENT=`echo -n "$DISTMILES Miles $COMMENT"`
					 MWPERMILE=`echo "scale=2; $WATTS*1000/$DISTMILES" | bc`
                        		 echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n<td>$MWPERMILE</td>\n</tr>" >> $HTMLFILENAME
                        		 echo -e "</table>\n<p>" >> $HTMLFILENAME
						;;

				   "km") DISTKM=`$WWL $MYGRIDSQ $GRIDSQUARE | awk '{print $2}'`
					 COMMENT=`echo -n "$DISTKM km $COMMENT"`
					 MWPERKM=`echo "scale=2; $WATTS*1000/$DISTKM" | bc`
					 echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n<td>$MWPERKM</td>\n</tr>" >> $HTMLFILENAME
                                         echo -e "</table>\n<p>" >> $HTMLFILENAME
                                                ;;


			esac
        fi

	# Header for main log data table
	echo -e "<table style=\"width:100%\">\n<tr>\n<th>QSO DATE</th>\n<th>DX CALLSIGN</th>\n<th>DX GRID</th>\n<th>MODE</th>\n<th>SNR SENT</th>\n<th>SNR RXD</th>\n<th>TIME ON</th>\n<th>TIME OFF</th>\n<th>BAND</th>\n<th>FREQ Mhz</th>\n<th>TX PWR</th>\n<th>COMMENT</th>\n<th>mW/Mile</th>\n</tr>" >> $HTMLFILENAME
}


function write_html_footer() {
	echo "Writing HTML footer ..."
	echo -e "</table>\n<p>Web page generated by adi2html.sh $VERSION by M0AWS <a href=\"http://m0aws.co.uk\">http://m0aws.co.uk</a></p>\n</body>\n</html>\n" >> $HTMLFILENAME
}

############################
# main()

echo "adi2html.sh $VERSION by M0AWS"
echo "========================="

if [ "$1" ]
	then
		ADIFILENAME=$1
		HTMLFILENAME=`echo $ADIFILENAME | sed 's/log/html/g' | sed 's/adi/html/g' | sed 's/adif/html/g'`
		LOGMODE=`echo $2 | tr '[:lower:]' '[:upper:]'`
		echo "ADIFILENAME set to $ADIFILENAME"
		echo "LOGMODE set to $LOGMODE"
		case $LOGMODE in

			"") echo "Error! No LOGMODE passed as option 2 when called, exiting!"
			    exit 1
				;;

		      "CW") MAPFILE="m0aws-cw-log-map.png"
				;;

		     "SSB") MAPFILE="m0aws-ssb-log-map.png"
				;;

		      "FM") MAPFILE="m0aws-fm-log-map.png"
				;;

		     "WSJT"|"WSJTX"|"WSJT-X") MAPFILE="m0aws-wsjtx-log-map.png" # Not necessary but here for completeness
					      HTMLFILENAME="WSJT_log.html"
				;;
			    

		esac
		echo "HTMLFILENAME set to $HTMLFILENAME"
		echo "MAPFILE set to $MAPFILE"
fi

case $WWL in

	"") echo "Error: wwl not installed on this system, please run: sudo apt install wwl"
	    exit 2
		;;
esac

echo "Calculating Band stats ..."

COUNT160M=`grep ">160m" $ADIFILENAME | wc -l`
COUNT80M=`grep ">80m" $ADIFILENAME | wc -l`
COUNT60M=`grep ">60m" $ADIFILENAME | wc -l`
COUNT40M=`grep ">40m" $ADIFILENAME | wc -l`
COUNT30M=`grep ">30m" $ADIFILENAME | wc -l`
COUNT20M=`grep ">20m" $ADIFILENAME | wc -l`
COUNT17M=`grep ">17m" $ADIFILENAME | wc -l`
COUNT15M=`grep ">15m" $ADIFILENAME | wc -l`
COUNT12M=`grep ">12m" $ADIFILENAME | wc -l`
COUNT10M=`grep ">10m" $ADIFILENAME | wc -l`
COUNT6M=`grep ">6m" $ADIFILENAME | wc -l`
COUNT4M=`grep ">4m" $ADIFILENAME | wc -l`
COUNT2M=`grep ">2m" $ADIFILENAME | wc -l`
COUNT70CM=`grep ">70cm" $ADIFILENAME | wc -l`
let TOTAL=COUNT160M+COUNT80M+COUNT60M+COUNT40M+COUNT30M+COUNT20M+COUNT17M+COUNT15M+COUNT12M+COUNT10M+COUNT6M+COUNT4M+COUNT2M+COUNT70CM

echo "Setting platform specific dependencies ..."
case $OSTYPE in

	darwin20) # MacOS
		  TAC="tail -r"
		  ;;

	       *) # Linux
		  TAC="tac"
		  ;;
esac

process_log
write_html_header
echo "Building webpage body ..."
cat $TEMPFILE1 >> $HTMLFILENAME
write_html_footer
rm $TEMPFILE1 $TEMPFILE2 $TEMPFILE3
END=`date +%s`
RUNTIME=$( echo "$END - $START" | bc -l )
echo "Processed $TOTAL log entries in $RUNTIME seconds"
exit


